@@ -84,7 +84,7 @@ public:
     bool isHeaderEncryptionEnabled() const;
 
 public slots:
-    virtual void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 
 private:
     void loadConfiguration();
@@ -94,7 +94,6 @@ private:
     KConfigGroup m_config;
     QStringList m_supportedMimeTypes;
     PluginManager m_pluginManger;
-    CompressionOptions m_compOptions;
 
 private slots:
     void slotFileNameEdited(const QString &text);
