@@ -207,7 +207,9 @@ void Job::onFinished(bool result)
         setError(KJob::UserDefinedError);
     }
 
-    emitResult();
+    if (!d->isInterruptionRequested()) {
+        emitResult();
+    }
 }
 
 void Job::onUserQuery(Query *query)
@@ -221,16 +223,22 @@ void Job::onUserQuery(Query *query)
 
 bool Job::doKill()
 {
-    if (d->isRunning()) {
-        d->requestInterruption();
-        d->wait();
+    const bool canKillJob = archiveInterface()->doKill();
+
+    if (!d->isRunning()) {
+        return canKillJob;
     }
 
-    bool ret = archiveInterface()->doKill();
-    if (!ret) {
-        qCWarning(ARK) << "Killing does not seem to be supported here.";
+    d->requestInterruption();
+
+    if (!canKillJob) {
+        qCDebug(ARK) << "Forcing thread exit in one second...";
+        d->wait(1000);
+        return true;
     }
-    return ret;
+
+    d->wait();
+    return canKillJob;
 }
 
 LoadJob::LoadJob(Archive *archive, ReadOnlyArchiveInterface *interface)
@@ -271,7 +279,7 @@ void LoadJob::doWork()
 
 void LoadJob::onFinished(bool result)
 {
-    if (archive()) {
+    if (archive() && result) {
         archive()->setProperty("unpackedSize", extractedFilesSize());
         archive()->setProperty("isSingleFolder", isSingleFolderArchive());
         const auto name = subfolderName().isEmpty() ? archive()->completeBaseName() : subfolderName();
@@ -465,7 +473,7 @@ void CreateJob::setMultiVolume(bool isMultiVolume)
 
 void CreateJob::doWork()
 {
-    m_addJob = archive()->addFiles(m_entries, new Archive::Entry(this), m_options);
+    m_addJob = archive()->addFiles(m_entries, nullptr, m_options);
 
     if (m_addJob) {
         connect(m_addJob, &KJob::result, this, &CreateJob::emitResult);
