@@ -29,16 +29,16 @@
 #define PREVIEWSETTINGSPAGE_H
 
 #include "settingspage.h"
-#include "ui_previewsettings.h"
+#include "ui_previewsettingspage.h"
 
 namespace Kerfuffle
 {
-class KERFUFFLE_EXPORT PreviewSettingsPage : public SettingsPage, public Ui::PreviewSettings
+class KERFUFFLE_EXPORT PreviewSettingsPage : public SettingsPage, public Ui::PreviewSettingsPage
 {
     Q_OBJECT
 
 public:
-    explicit PreviewSettingsPage(QWidget *parent = 0, const QString &name = QString(), const QString &iconName = QString());
+    explicit PreviewSettingsPage(QWidget *parent = nullptr, const QString &name = QString(), const QString &iconName = QString());
 
 private slots:
     void slotToggled(bool enabled);
